@@ -1,15 +1,9 @@
 import requests, os, json, time
 from ftThanos.notion_get_properties import *
 from ftThanos.notion_update_properties import *
+from ftThanos.log import *
 
 class notion_connector:
-	ESC = "\x1b"
-	BLACK = ESC + "[30m"
-	BLUE = ESC + "[34m"
-	RED = ESC + "[31m"
-	GREEN = ESC + "[32m"
-	DEFAULT = ESC + "[39m"
-	verbose = False
 
 ###############
 # Main fonction
@@ -27,15 +21,15 @@ class notion_connector:
 		self.all_users = (json.loads(requests.get(self.url + '/users', headers=self.head).text))['results']
 		self.update = update_properties(users_list=self.all_users)
 		self.verbose = True
-		print(self.BLUE + "[NOTION CONNECTOR] Verbose activate." + self.DEFAULT)
-		print(self.GREEN + "[NOTION CONNECTOR] Connector ready to use! " + self.BLUE + "(If you need some information : helper() - or thanos@42paris.fr)" + self.DEFAULT)
+		message("NOTION :: Ready to use.")
 
 #############################################
 # Helper présentant les différentes commandes
 #############################################
 	def helper(self):
 		print('[NOTION CONNECTOR] All function available :')
-		print("\t- \"put_in_file([data],[*name])\" -> Will put the data in file, if name param was given, file will take the name, else file will be name output.json.")
+		print("\t- \"put_in_file([data],[*name])\" -> Will put the data in file, if name param was given, file will "
+			  "take the name, else file will be name output.json.")
 		print("\t- \"getDb(dbId)\" -> Activate verbose.")
 		print("\t- \"updateDb(pageId, data)\" -> Activate verbose.")
 		print("\t- \"createDb(parentId)\" -> Activate verbose.")
@@ -51,6 +45,13 @@ class notion_connector:
 # Créateur de .json avec de la data
 ###################################
 	def put_in_file(self, data, *args):
+		"""
+		Take a dict object and put it in notion_output.json.\n
+		If name of destination file given, data was put in destination file .json
+		:param data: Dict object
+		:param args: Name of destination file
+		:return: None
+		"""
 		to_write = json.dumps(data, indent=4, sort_keys=True)
 		if len(args) > 0:
 			name = 'notion_' + args[0]
@@ -61,12 +62,18 @@ class notion_connector:
 		output = open(name, 'w')
 		for line in to_write:
 			output.write(line)
-		print(self.GREEN + f"[NOTION CONNECTOR] Data was put in {name}." + self.DEFAULT)
+		message(f"NOTION ::  Data was put in {name}.")
 
 ################
 # Parser de .env
 ################
+	@staticmethod
 	def dot_env_parser(self):
+		"""
+		Parse .env
+		:param: None
+		:return: return dict object with 'TOKEN'
+		"""
 		ret = {}
 		try :
 			with open ('.env', 'r') as file:
@@ -76,15 +83,20 @@ class notion_connector:
 						continue
 					ret[lst[0]] = lst[1][:-1]
 		except IOError:
-			exit(print(self.RED + '[NOTION CONNECTOR] No .env detected.' + self.DEFAULT))
+			exit(critical('NOTION :: No .env detected.'))
 		if not 'TOKEN' in ret:
-			exit(print(self.RED + '[NOTION CONNECTOR] Wrong parameters in .env, you should put in your file:\nTOKEN=[Your notion token]' + self.DEFAULT))
-		return (ret)
+			exit(critical('NOTION :: Wrong parameters in .env, you should put in your file:\nTOKEN=[Your notion token]'))
+		return ret
 
 ###############################
 # Utilisation sur les databases
 ###############################
 	def getDb(self, dbId):
+		"""
+		Get a Notion Database and return it format for easily work.
+		:param dbId: ID of Notion DB you want to get.
+		:return: Pages of the DB with properties format.
+		"""
 		url = self.url + '/databases/' + dbId + '/query'
 		body = {
 			"sorts": [],
@@ -92,7 +104,7 @@ class notion_connector:
 		}
 		data = []
 		end_reply = {"next_cursor" : None}
-		try :
+		try:
 			while (True):
 				if end_reply['next_cursor'] is not None:
 					if end_reply['has_more'] == True:
@@ -107,7 +119,9 @@ class notion_connector:
 					break
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), 'error.json')
-			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + ' on POST ' + url + self.DEFAULT)
+			error('NOTION :: ' + str(err) + ' on POST ' + url)
+			return None
+		success(f'NOTION :: GET on DB {dbId}')
 		ret = []
 		for line in data:
 			data_line = {
@@ -119,23 +133,35 @@ class notion_connector:
 					data_line['title'] = self.getProperties(i[1])['value']
 				data_line['properties'][i[0]] = self.getProperties(i[1])
 			ret.append(data_line)
-		return (ret)
+		success(f'NOTION :: Dd {dbId} formatted')
+		return ret
 
 #################################################
 # Search title in db and return it if exist, else return None
 #################################################
 	def getTitle(self, db, title):
-		print(title)
+		"""
+		Take a database format and search a given title. If title was found, return line, else return None
+		:param db: DB format from getDb()
+		:param title: Title you want to qwery in Database
+		:return: title in DB return page or None
+		"""
 		for line in db:
 			if 'title' in line.keys():
 				if line['title'] == title:
-					return (line)
+					return line
 		return None
 
 #################################################
 # Permet de mettre à jour une des lignes de la db
 #################################################
-	def updateDb(self, pageId, properties):
+	def updatePageProperties(self, pageId, properties):
+		"""
+		Update a page with properties who are given in parameters.
+		:param pageId: ID's page you want to update.
+		:param properties: Properties for update page.
+		:return: return reply.
+		"""
 		data = {'properties': {}}
 		i = False
 		for i in properties.items():
@@ -144,22 +170,27 @@ class notion_connector:
 				del data['properties'][i[0]]
 				continue
 			i = True
-		if i == False:
+		if not i:
 			return
 		url = self.url + '/pages/' + pageId
 		try :
 			reply = requests.patch(url, headers=self.head, data=json.dumps(data))
 			reply.raise_for_status()
-			print(self.GREEN + "[NOTION CONNECTOR] Success PATCH on " + url + self.DEFAULT)
+			success(f'NOTION :: PATCH on page {pageId} - update properties')
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), 'error.json')
-			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + ' on PATCH ' + url + self.DEFAULT)
-		return (json.loads(reply.text))
+			error('NOTION :: ' + str(err) + f' PATCH on page {pageId} - - update properties')
+		return json.loads(reply.text)
 
 ##################################
 # Créé une nouvelle base de donnée
 ##################################
 	def createDb(self, parentId):
+		"""
+		Create DB.
+		:param parentId: Place where you want to create DB.
+		:return: Return Data of db.
+		"""
 		url = self.url + '/blocks/' + parentId + '/children'
 		data = {
 			"children": [
@@ -175,26 +206,36 @@ class notion_connector:
 		try :
 			reply = requests.patch(url, hearders=self.head, data=json.dumps(data))
 			reply.raise_for_status()
-			if self.verbose == True:
-				print(self.GREEN + "[NOTION CONNECTOR] Success PATCH on " + url + self.DEFAULT)
+			success(f"NOTION :: PATCH on {parentId} - Creating DB")
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), 'error.json')
-			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + ' on PATCH ' + url + self.DEFAULT)
-		return (json.loads(reply.text))
+			error(f'NOTION :: ' + str(err) + f' PATCH on {parentId} - Creating DB')
+		return json.loads(reply.text)
 
 ###################################
 # Retourne le champs title de la db
 ###################################
 	def getTitleProperties(self, db):
+		"""
+		For a given Db, return the name of column Title
+		:param db: DB where you want search the name of the title
+		:return: return name of title
+		"""
 		line = db[0]['properties']
 		for i in line.items():
 			if i[1]['properties']['type'] == 'title':
-				return(i[0])
+				return i[0]
 
 ############################################################################
 # Rajoute une ligne à la base de donnée, avec pour title le nom mis en param
 ############################################################################
 	def addPageDb(self, dbId, name):
+		"""
+		Add a page on a given DB
+		:param dbId: DB where you want to add a page.
+		:param name: Name of title for new page.
+		:return: All the line format
+		"""
 		title = self.getTitleProperties(self.getDb(dbId))
 		url = self.url + '/pages'
 		data = {
@@ -215,11 +256,10 @@ class notion_connector:
 		try :
 			reply = requests.post(url, headers=self.head, data=json.dumps(data))
 			reply.raise_for_status()
-			if self.verbose == True:
-				print(self.GREEN + "[NOTION CONNECTOR] Success POST on " + url + self.DEFAULT)
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), 'error.json')
-			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + ' on POST ' + url + self.DEFAULT)
+			print(self.RED + 'NOTION :: ' + str(err) + f' POST on {dbId} - Creating page {name}')
+		success(f"NOTION :: POST on {dbId} - Creating page {name}")
 		line = json.loads(reply.text)
 		data_line = {
 			'page_id' : line['id'],
@@ -229,30 +269,34 @@ class notion_connector:
 			if i[1]['type'] == 'title':
 				data_line['title'] = self.getProperties(i[1])['value']
 			data_line['properties'][i[0]] = self.getProperties(i[1])
-		return(data_line)
+		return data_line
 
 #############################################
 # Récupère la l'id de la ligne de la Database
 #############################################
 	def getIdLine(self, elem):
-		return(elem['id'])
+		return elem['id']
 
 #####################################################
 # Récupère la fonction pour avoir un obj de propriété
 #####################################################
 	def getProperties(self, elem):
-		return (get_properties(elem))
+		return get_properties(elem)
 
 ##################################################
 # Met à jour une propriété avec les elements voulu
 ##################################################
 	def updateProperties(self, elem):
-		return (self.update.update_properties(elem))
+		return self.update.update_properties(elem)
 
 ##################################################
 # Recupère tout les utilisateurs de l'access token
 ##################################################
 	def getAllUsers(self):
+		"""
+		Get all user of the space.
+		:return: return user data.
+		"""
 		url = self.url + '/users'
 		ret = []
 		try :
@@ -260,23 +304,9 @@ class notion_connector:
 			reply.raise_for_status()
 			end_reply = json.loads(reply.text)
 			ret += end_reply['results']
-			if self.verbose == True:
-				print(self.GREEN + "[NOTION CONNECTOR] Success POST on " + url + self.DEFAULT)
+			success(f"NOTION :: Success GET on {url} - Get all users")
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), 'error.json')
-			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + 'on GET ' + url + self.DEFAULT)
-		return (ret)
+			error('NOTION :: ' + str(err) + f'on GET {url} - Get all users')
+		return ret
 
-#####################################
-# Active le mode verbose du connector
-#####################################
-	def verbose(self):
-		self.verbose = True
-		print(self.BLUE + "[NOTION CONNECTOR] Verbose activate." + self.DEFAULT)
-
-########################################
-# Desactive le mode verbose du connector
-########################################
-	def unverbose(self):
-		self.verbose = False
-		print(self.BLUE + "[NOTION CONNECTOR] Verbose desactivate." + self.DEFAULT)
